<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Neplatný polomer</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Žiadne riašenie</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translation>Vyberte prvok alebo oblasť</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translation>Presunúť prvok alebo referenčný bod</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translation>Nastaviť druhý roh</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translation>Určte cieľový bod referenčného bodu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translation>Určte cieľový bod výberu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Presunúť prvok na požadované miesto</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Presunúť referenčný bod</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Presunúť Výber</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Presunúť prvok</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Úprava bloku &apos;%1&apos;&lt;br&gt;Vybrať &lt;i&gt;Blok &gt; Návrat ku kresleniu &lt;/i&gt; keď bude hotové</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Aktívny Nástroj:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Žiadne</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translation type="vanished">Možnosti bloku</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translation>Hlavné Nástroje</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>CAD Nástroje</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translation>Prvok je na zamknutej vrstve.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Dĺžka:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translation>Prvok nie je blok.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translation>Prvok nie je čiara alebo oblúk.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Prvok nie je čiara, oblúk alebo krivka.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translation>Prvok nie je čiara.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translation>Prvok nie je oblúk alebo kružnica.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translation>Prvok nie je čiara, oblúk alebo kružnica.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translation>Prvok nie je oblúk, kružnica alebo elipsa.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Prvok nie je čiara, oblúk, kružnica alebo elipsa.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Prvok nie je čiara, oblúk, kružnica, elipsa alebo krivka.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Prvok nie je čiara, oblúk, kružnica, elipsa alebo Spline.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Prvok nie je čiara, oblúk, kružnica, elipsa, spline alebo krivka.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translation>Prvok nie je krivka.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Polomer klesol pod 0.0 po %1 sústredných kružniciach.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Polomer klesol pod 0.0 po %1 sústredných oblúkoch.</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translation>Minimálne dva body sú rovnaké.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translation>Kružnica sa nedá vytvoriť.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Oblúk sa nedá vytvoriť.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translation>Chybný počet častí: %1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translation>Neplatný hlavný polomer k vedľajšiemu: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Obnoviť predvolené</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Vložiť znak</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Priemer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Oblúk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Stupeň</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Plus/Mínus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Takmer sa rovná</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asymptoticky sa rovná</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Druhá odmocnina</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Fí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>fí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Alt fí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Násobenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Delenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Mocnina</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translation>Text pod sebou</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translation>Nameraná hodnota</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Stred</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Zarovnané</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Polovica</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Prispôsobiť</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Hore</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Základ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation type="unfinished">Žiadne</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Nahrávanie prekladového doplnku...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Nahrávanie doplnkov...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Inicializácia doplnkov...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Inicializácia doplnkov:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Post-inicializácia doplnkov...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Objekty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Neznáme objekty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Neznámy objekt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Bloky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Vrstvy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Vrstva</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Usporiadania</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Usporiadanie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Typy čiar</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Typ čiary</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Zobrazenia</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Zobrazenie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Prvok</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Prvky</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translation>3d Plochy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translation>3d Plocha</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Blok a Vlastnosti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Blok a Vlastnosti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>Oblúky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Oblúk</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Vlastnosť</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Definícia Vlastností</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Definícia Vlastnosti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Kružnice</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Kružnica</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Kóty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Kóta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translation>Rovnobežné Kóty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translation>Rovnobežná Kóta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translation>Uhlové Kóty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translation>Uhlová Kóta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translation>Kóty Priamerov</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translation>Kóta Priemeru</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translation>Súradnicové Kóty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translation>Súradnicová Kóta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translation>Natočené Kóty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translation>Natočená Kóta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translation>Kóty Polomerov</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translation>Kóta Polomeru</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Elipsy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>Šrafovania</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>Šrafovanie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>Obrázok</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translation>Odkazové čiary</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translation>Odkazová čiara</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Čiary</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Čiara</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Priamky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Priamka</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Polpriamky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Polpriamka</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Body</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Bod</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Krivky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Krivka</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translation>Výplne</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translation>Výplň</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Stopy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Stopa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Plochy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Plocha</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Spline-y</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Základný text</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Texty</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Rezy</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Rez</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translation>Neznáme Prvky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translation>Neznámy Prvok</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Prvý prvok sa nedá odrezať.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Prvok sa nedá odrezať.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Druhý prvok sa nedá odrezať.</translation>
    </message>
</context>
</TS>
